==> haskell-lift-type-0.1.2.0-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lift-type.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lift-type
version:              0.1.2.0
visibility:           public
id:                   lift-type-0.1.2.0-44J021UlEb06ryhdW5Ncp3
key:                  lift-type-0.1.2.0-44J021UlEb06ryhdW5Ncp3
license:              BSD-3-Clause
copyright:            2021 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/lift-type#readme
synopsis:
    Lift a type from a Typeable constraint to a Template Haskell type

description:
    Lift your types from a Typeable constraint to a Template Haskell type

abi:                  8b2555b0976bf1b81fc30382a66b8fa5
exposed:              True
exposed-modules:      LiftType
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lift-type
hs-libraries:         HSlift-type-0.1.2.0-44J021UlEb06ryhdW5Ncp3
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-lift-type/html/lift-type.haddock
haddock-html:         /usr/share/doc/haskell-lift-type/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lift-type-0.1.2.0-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lift-type.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lift-type
version:              0.1.2.0
visibility:           public
id:                   lift-type-0.1.2.0-CwTWxfQY174GlgYsSkSMgq
key:                  lift-type-0.1.2.0-CwTWxfQY174GlgYsSkSMgq
license:              BSD-3-Clause
copyright:            2021 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/lift-type#readme
synopsis:
    Lift a type from a Typeable constraint to a Template Haskell type

description:
    Lift your types from a Typeable constraint to a Template Haskell type

abi:                  13f4d1cffec5c9a4abc93c7d7388d56f
exposed:              True
exposed-modules:      LiftType
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lift-type
hs-libraries:         HSlift-type-0.1.2.0-CwTWxfQY174GlgYsSkSMgq
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-lift-type/html/lift-type.haddock
haddock-html:         /usr/share/doc/haskell-lift-type/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
